==> kubernetes-model-apps-6.0.0-sources.jar: io/fabric8/kubernetes/api/model/apps/DaemonSetFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apps;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DaemonSetFluentImpl<A extends DaemonSetFluent<A>> extends BaseFluent<A> implements DaemonSetFluent<A>{
  public DaemonSetFluentImpl() {
  }
  public DaemonSetFluentImpl(DaemonSet instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private DaemonSetSpecBuilder spec;
  private DaemonSetStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public DaemonSetFluent.MetadataNested<A> withNewMetadata() {
    return new DaemonSetFluentImpl.MetadataNestedImpl();
  }
  public DaemonSetFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new DaemonSetFluentImpl.MetadataNestedImpl(item);
  }
  public DaemonSetFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public DaemonSetFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public DaemonSetFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public DaemonSetSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public DaemonSetSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(DaemonSetSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new DaemonSetSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public DaemonSetFluent.SpecNested<A> withNewSpec() {
    return new DaemonSetFluentImpl.SpecNestedImpl();
  }
  public DaemonSetFluent.SpecNested<A> withNewSpecLike(DaemonSetSpec item) {
    return new DaemonSetFluentImpl.SpecNestedImpl(item);
  }
  public DaemonSetFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public DaemonSetFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new DaemonSetSpecBuilder().build());
  }
  public DaemonSetFluent.SpecNested<A> editOrNewSpecLike(DaemonSetSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public DaemonSetStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public DaemonSetStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(DaemonSetStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new DaemonSetStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public DaemonSetFluent.StatusNested<A> withNewStatus() {
    return new DaemonSetFluentImpl.StatusNestedImpl();
  }
  public DaemonSetFluent.StatusNested<A> withNewStatusLike(DaemonSetStatus item) {
    return new DaemonSetFluentImpl.StatusNestedImpl(item);
  }
  public DaemonSetFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public DaemonSetFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new DaemonSetStatusBuilder().build());
  }
  public DaemonSetFluent.StatusNested<A> editOrNewStatusLike(DaemonSetStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DaemonSetFluentImpl that = (DaemonSetFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<DaemonSetFluent.MetadataNested<N>> implements DaemonSetFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) DaemonSetFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends DaemonSetSpecFluentImpl<DaemonSetFluent.SpecNested<N>> implements DaemonSetFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(DaemonSetSpec item) {
      this.builder = new DaemonSetSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new DaemonSetSpecBuilder(this);
    }
    DaemonSetSpecBuilder builder;
    public N and() {
      return (N) DaemonSetFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends DaemonSetStatusFluentImpl<DaemonSetFluent.StatusNested<N>> implements DaemonSetFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(DaemonSetStatus item) {
      this.builder = new DaemonSetStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new DaemonSetStatusBuilder(this);
    }
    DaemonSetStatusBuilder builder;
    public N and() {
      return (N) DaemonSetFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-apps-6.7.2-sources.jar: io/fabric8/kubernetes/api/model/apps/DaemonSetFluentImpl.java <==
package io.fabric8.kubernetes.api.model.apps;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DaemonSetFluentImpl<A extends DaemonSetFluent<A>> extends BaseFluent<A> implements DaemonSetFluent<A>{
  public DaemonSetFluentImpl() {
  }
  public DaemonSetFluentImpl(DaemonSet instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private DaemonSetSpecBuilder spec;
  private DaemonSetStatusBuilder status;
  private Map<String,Object> additionalProperties;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public DaemonSetFluentImpl.MetadataNested<A> withNewMetadata() {
    return new DaemonSetFluentImpl.MetadataNestedImpl();
  }
  public DaemonSetFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new DaemonSetFluentImpl.MetadataNestedImpl(item);
  }
  public DaemonSetFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public DaemonSetFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public DaemonSetFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public DaemonSetSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public DaemonSetSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(DaemonSetSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new DaemonSetSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public DaemonSetFluentImpl.SpecNested<A> withNewSpec() {
    return new DaemonSetFluentImpl.SpecNestedImpl();
  }
  public DaemonSetFluentImpl.SpecNested<A> withNewSpecLike(DaemonSetSpec item) {
    return new DaemonSetFluentImpl.SpecNestedImpl(item);
  }
  public DaemonSetFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public DaemonSetFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new DaemonSetSpecBuilder().build());
  }
  public DaemonSetFluentImpl.SpecNested<A> editOrNewSpecLike(DaemonSetSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public DaemonSetStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public DaemonSetStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(DaemonSetStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new DaemonSetStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public DaemonSetFluentImpl.StatusNested<A> withNewStatus() {
    return new DaemonSetFluentImpl.StatusNestedImpl();
  }
  public DaemonSetFluentImpl.StatusNested<A> withNewStatusLike(DaemonSetStatus item) {
    return new DaemonSetFluentImpl.StatusNestedImpl(item);
  }
  public DaemonSetFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public DaemonSetFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new DaemonSetStatusBuilder().build());
  }
  public DaemonSetFluentImpl.StatusNested<A> editOrNewStatusLike(DaemonSetStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DaemonSetFluentImpl that = (DaemonSetFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<DaemonSetFluentImpl.MetadataNested<N>> implements DaemonSetFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) DaemonSetFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends DaemonSetSpecFluentImpl<DaemonSetFluentImpl.SpecNested<N>> implements DaemonSetFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(DaemonSetSpec item) {
      this.builder = new DaemonSetSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new DaemonSetSpecBuilder(this);
    }
    DaemonSetSpecBuilder builder;
    public N and() {
      return (N) DaemonSetFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends DaemonSetStatusFluentImpl<DaemonSetFluentImpl.StatusNested<N>> implements DaemonSetFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(DaemonSetStatus item) {
      this.builder = new DaemonSetStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new DaemonSetStatusBuilder(this);
    }
    DaemonSetStatusBuilder builder;
    public N and() {
      return (N) DaemonSetFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
